@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2015-2022 MinIO, Inc.
+// Copyright (c) 2015-2024 MinIO, Inc.
 //
 // This file is part of MinIO Object Storage stack
 //
@@ -69,8 +69,10 @@ const (
 
 	LambdaWebhookSubSys = "lambda_webhook"
 
-	BrowserSubSys         = "browser"
-	AuditEventQueueSubSys = "audit_event_queue"
+	BrowserSubSys          = "browser"
+	AuditEventQueueSubSys  = "audit_event_queue"
+	ErasureSubSys          = "erasure"
+	BucketEventQueueSubSys = "bucket_event_queue"
 )
 
 // SubSystems - list of all subsystems in MinIO
@@ -154,6 +156,8 @@ var EOSSubSystems = set.CreateStringSet(
 	LambdaWebhookSubSys,
 	BrowserSubSys,
 	AuditEventQueueSubSys,
+	ErasureSubSys,
+	BucketEventQueueSubSys,
 )
 
 // Standard config keys and values.
